@@ -1,3 +1,5 @@
+require 'active_support/json'
+
 module ActiveResource
   module Formats
     module JsonFormat
@@ -11,8 +13,8 @@ module ActiveResource
         "application/json"
       end
 
-      def encode(hash, options={})
-        hash.to_json(options)
+      def encode(hash, options = nil)
+        ActiveSupport::JSON.encode(hash, options)
       end
 
       def decode(json)
